==> Topsis_101703218_Harsh-0.1.tar.gz: Topsis_101703218_Harsh-0.1/setup.py <==


from distutils.core import setup
setup(
  name = 'Topsis_101703218_Harsh',         # How you named your package folder (MyLib)
  packages = ['Topsis_101703218_Harsh'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'this is a library to perform topsis technique',   # Give a short description about your library
  author = 'Harsh',                   # Type in your name
  author_email = 'agarwalharsh.502@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/harsh7502/Topsis_101703218_harsh',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/harsh7502/Topsis_101703218_harsh/archive/v0.1.tar.gz',    # I explain this later on
  keywords = ['Topsosis', 'Rank', 'best feature'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> Topsis_101703218_Harsh-0.2.tar.gz: Topsis_101703218_Harsh-0.2/setup.py <==


from distutils.core import setup
setup(
  name = 'Topsis_101703218_Harsh',         # How you named your package folder (MyLib)
  packages = ['Topsis_101703218_Harsh'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'this is a library to perform topsis technique',   # Give a short description about your library
  author = 'Harsh',                   # Type in your name
  author_email = 'agarwalharsh.502@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/harsh7502/Topsis_101703218_harsh',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/harsh7502/Topsis_101703218_harsh/archive/0.2.tar.gz',    # I explain this later on
  keywords = ['Topsosis', 'Rank', 'best feature'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
